@@ -448,8 +448,6 @@ const AppSwitcher = new Lang.Class({
             });
             if (appIcon.cachedWindows.length > 0)
                 this._addIcon(appIcon);
-            else if (workspace == null)
-                throw new Error('%s appears to be running, but doesn\'t have any windows'.format(appIcon.app.get_name()));
         }
 
         this._curApp = -1;
@@ -687,15 +685,17 @@ const WindowIcon = new Lang.Class({
 
         this._icon.destroy_all_children();
 
+        let scaleFactor = St.ThemeContext.get_for_stage(global.stage).scale_factor;
+
         switch (mode) {
             case AppIconMode.THUMBNAIL_ONLY:
                 size = WINDOW_PREVIEW_SIZE;
-                this._icon.add_actor(_createWindowClone(mutterWindow, WINDOW_PREVIEW_SIZE));
+                this._icon.add_actor(_createWindowClone(mutterWindow, size * scaleFactor));
                 break;
 
             case AppIconMode.BOTH:
                 size = WINDOW_PREVIEW_SIZE;
-                this._icon.add_actor(_createWindowClone(mutterWindow, WINDOW_PREVIEW_SIZE));
+                this._icon.add_actor(_createWindowClone(mutterWindow, size * scaleFactor));
 
                 if (this.app)
                     this._icon.add_actor(this._createAppIcon(this.app,
@@ -707,7 +707,7 @@ const WindowIcon = new Lang.Class({
                 this._icon.add_actor(this._createAppIcon(this.app, size));
         }
 
-        this._icon.set_size(size, size);
+        this._icon.set_size(size * scaleFactor, size * scaleFactor);
     },
 
     _createAppIcon: function(app, size) {
