@@ -14,6 +14,11 @@ const RENAMED_DESKTOP_IDS = {
     'gcalctool.desktop': 'gnome-calculator.desktop',
     'gedit.desktop': 'org.gnome.gedit.desktop',
     'glchess.desktop': 'gnome-chess.desktop',
+    'glines.desktop': 'five-or-more.desktop',
+    'gnect.desktop': 'four-in-a-row.desktop',
+    'gnibbles.desktop': 'gnome-nibbles.desktop',
+    'gnobots2.desktop': 'gnome-robots.desktop',
+    'gnome-boxes.desktop': 'org.gnome.Boxes.desktop',
     'gnome-clocks.desktop': 'org.gnome.clocks.desktop',
     'gnome-contacts.desktop': 'org.gnome.Contacts.desktop',
     'gnome-documents.desktop': 'org.gnome.Documents.desktop',
@@ -23,6 +28,9 @@ const RENAMED_DESKTOP_IDS = {
     'gnome-software.desktop': 'org.gnome.Software.desktop',
     'gnome-weather.desktop': 'org.gnome.Weather.Application.desktop',
     'gnomine.desktop': 'gnome-mines.desktop',
+    'gnotravex.desktop': 'gnome-tetravex.desktop',
+    'gnotski.desktop': 'gnome-klotski.desktop',
+    'gtali.desktop': 'tali.desktop',
     'nautilus.desktop': 'org.gnome.Nautilus.desktop',
     'polari.desktop': 'org.gnome.Polari.desktop',
     'totem.desktop': 'org.gnome.Totem.desktop',
