@@ -1,4 +1,5 @@
 const Clutter = imports.gi.Clutter;
+const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Meta = imports.gi.Meta;
 const Shell = imports.gi.Shell;
@@ -28,8 +29,9 @@ const STANDARD_TRAY_ICON_IMPLEMENTATIONS = {
 };
 
 // Offset of the original position from the bottom-right corner
-const CONCEALED_VISIBLE_FRACTION = 0.2;
+const CONCEALED_WIDTH = 3;
 const REVEAL_ANIMATION_TIME = 0.2;
+const TEMP_REVEAL_TIME = 2;
 
 const BARRIER_THRESHOLD = 70;
 const BARRIER_TIMEOUT = 1000;
@@ -100,6 +102,7 @@ const LegacyTray = new Lang.Class({
 
         Main.layoutManager.addChrome(this.actor, { affectsInputRegion: false });
         Main.layoutManager.trackChrome(this._slider, { affectsInputRegion: true });
+        Main.uiGroup.set_child_below_sibling(this.actor, Main.layoutManager.modalDialogGroup);
         Main.ctrlAltTabManager.addGroup(this.actor,
                                         _("Status Icons"), 'focus-legacy-systray-symbolic',
                                         { sortGroup: CtrlAltTab.SortGroup.BOTTOM });
@@ -173,7 +176,15 @@ const LegacyTray = new Lang.Class({
             }));
 
         this._iconBox.add_actor(button);
-        this._sync();
+
+        if (!this._concealHandle.visible) {
+            this._concealHandle.show();
+            GLib.timeout_add_seconds(GLib.PRIORITY_DEFAULT, TEMP_REVEAL_TIME,
+                Lang.bind(this, function() {
+                    this._concealHandle.hide();
+                    return GLib.SOURCE_REMOVE;
+                }));
+        }
     },
 
     _onTrayIconRemoved: function(tm, icon) {
@@ -204,11 +215,7 @@ const LegacyTray = new Lang.Class({
             this._horizontalBarrier.y2 == y2)
             return;
 
-        if (this._horizontalBarrier) {
-            this._pressureBarrier.removeBarrier(this._horizontalBarrier);
-            this._horizontalBarrier.destroy();
-            this._horizontalBarrier = null;
-        }
+        this._unsetBarrier();
 
         let directions = (rtl ? Meta.BarrierDirection.NEGATIVE_X : Meta.BarrierDirection.POSITIVE_X);
         this._horizontalBarrier = new Meta.Barrier({ display: global.display,
@@ -218,6 +225,15 @@ const LegacyTray = new Lang.Class({
         this._pressureBarrier.addBarrier(this._horizontalBarrier);
     },
 
+    _unsetBarrier: function() {
+        if (this._horizontalBarrier == null)
+            return;
+
+        this._pressureBarrier.removeBarrier(this._horizontalBarrier);
+        this._horizontalBarrier.destroy();
+        this._horizontalBarrier = null;
+    },
+
     _sync: function() {
         // FIXME: we no longer treat tray icons as notifications
         let allowed = Main.sessionMode.hasNotifications;
@@ -238,17 +254,20 @@ const LegacyTray = new Lang.Class({
             let [, boxWidth] = this._box.get_preferred_width(-1);
             let [, handleWidth] = this._revealHandle.get_preferred_width(-1);
 
-            targetSlide = handleWidth / boxWidth;
-            if (!this._revealHandle.hover)
-                targetSlide *= CONCEALED_VISIBLE_FRACTION;
+            if (this._revealHandle.hover)
+                targetSlide = handleWidth / boxWidth;
+            else
+                targetSlide = CONCEALED_WIDTH / boxWidth;
         }
 
-        if (this.actor.visible)
+        if (this.actor.visible) {
             Tweener.addTween(this._slideLayout,
                              { slideX: targetSlide,
                                time: REVEAL_ANIMATION_TIME,
                                transition: 'easeOutQuad' });
-        else
+        } else {
             this._slideLayout.slideX = targetSlide;
+            this._unsetBarrier();
+        }
     }
 });
