@@ -97,8 +97,6 @@ const WorkspacesView = new Lang.Class({
         this._scrolling = false; // swipe-scrolling
         this._animatingScroll = false; // programatically updating the adjustment
 
-        this._settings = new Gio.Settings({ schema_id: OVERRIDE_SCHEMA });
-
         let activeWorkspaceIndex = global.screen.get_active_workspace_index();
         this.scrollAdjustment = new St.Adjustment({ value: activeWorkspaceIndex,
                                                     lower: 0,
@@ -418,7 +416,7 @@ const WorkspacesDisplay = new Lang.Class({
         this.actor.connect('notify::allocation', Lang.bind(this, this._updateWorkspacesActualGeometry));
         this.actor.connect('parent-set', Lang.bind(this, this._parentSet));
 
-        let clickAction = new Clutter.ClickAction()
+        let clickAction = new Clutter.ClickAction();
         clickAction.connect('clicked', Lang.bind(this, function(action) {
             // Only switch to the workspace when there's no application
             // windows open. The problem is that it's too easy to miss
@@ -464,6 +462,7 @@ const WorkspacesDisplay = new Lang.Class({
 
         this._notifyOpacityId = 0;
         this._scrollEventId = 0;
+        this._keyPressEventId = 0;
 
         this._fullGeometry = null;
     },
@@ -495,6 +494,9 @@ const WorkspacesDisplay = new Lang.Class({
                                   Lang.bind(this, this._onRestacked));
         if (this._scrollEventId == 0)
             this._scrollEventId = Main.overview.connect('scroll-event', Lang.bind(this, this._onScrollEvent));
+
+        if (this._keyPressEventId == 0)
+            this._keyPressEventId = global.stage.connect('key-press-event', Lang.bind(this, this._onKeyPressEvent));
     },
 
     animateFromOverview: function(fadeOnPrimary) {
@@ -517,7 +519,10 @@ const WorkspacesDisplay = new Lang.Class({
             Main.overview.disconnect(this._scrollEventId);
             this._scrollEventId = 0;
         }
-
+        if (this._keyPressEventId > 0) {
+            global.stage.disconnect(this._keyPressEventId);
+            this._keyPressEventId = 0;
+        }
         for (let i = 0; i < this._workspacesViews.length; i++)
             this._workspacesViews[i].destroy();
         this._workspacesViews = [];
@@ -670,6 +675,25 @@ const WorkspacesDisplay = new Lang.Class({
         }
         Main.wm.actionMoveWorkspace(ws);
         return Clutter.EVENT_STOP;
+    },
+
+    _onKeyPressEvent: function(actor, event) {
+        if (!this.actor.mapped)
+            return Clutter.EVENT_PROPAGATE;
+        let activeWs = global.screen.get_active_workspace();
+        let ws;
+        switch (event.get_key_symbol()) {
+        case Clutter.KEY_Page_Up:
+            ws = activeWs.get_neighbor(Meta.MotionDirection.UP);
+            break;
+        case Clutter.KEY_Page_Down:
+            ws = activeWs.get_neighbor(Meta.MotionDirection.DOWN);
+            break;
+        default:
+            return Clutter.EVENT_PROPAGATE;
+        }
+        Main.wm.actionMoveWorkspace(ws);
+        return Clutter.EVENT_STOP;
     }
 });
 Signals.addSignalMethods(WorkspacesDisplay.prototype);
