@@ -156,16 +156,20 @@ static MetaWindow *
 window_backed_app_get_window (ShellApp     *app)
 {
   g_assert (app->info == NULL);
-  g_assert (app->running_state);
-  g_assert (app->running_state->windows);
-  return app->running_state->windows->data;
+  if (app->running_state)
+    {
+      g_assert (app->running_state->windows);
+      return app->running_state->windows->data;
+    }
+  else
+    return NULL;
 }
 
 static ClutterActor *
 window_backed_app_get_icon (ShellApp *app,
                             int       size)
 {
-  MetaWindow *window;
+  MetaWindow *window = NULL;
   ClutterActor *actor;
   gint scale;
   ShellGlobal *global;
@@ -181,14 +185,16 @@ window_backed_app_get_icon (ShellApp *app,
    * window-backend apps, it's possible we get a request for the icon.
    * Avoid asserting here and just return an empty image.
    */
-  if (app->running_state == NULL)
+  if (app->running_state != NULL)
+    window = window_backed_app_get_window (app);
+
+  if (window == NULL)
     {
       actor = clutter_texture_new ();
       g_object_set (actor, "opacity", 0, "width", (float) size, "height", (float) size, NULL);
       return actor;
     }
 
-  window = window_backed_app_get_window (app);
   actor = st_texture_cache_bind_cairo_surface_property (st_texture_cache_get_default (),
                                                         G_OBJECT (window),
                                                         "icon");
@@ -232,9 +238,10 @@ shell_app_get_name (ShellApp *app)
   else
     {
       MetaWindow *window = window_backed_app_get_window (app);
-      const char *name;
+      const char *name = NULL;
 
-      name = meta_window_get_wm_class (window);
+      if (window)
+        name = meta_window_get_wm_class (window);
       if (!name)
         name = C_("program", "Unknown");
       return name;
@@ -491,6 +498,9 @@ shell_app_activate_full (ShellApp      *app,
       case SHELL_APP_STATE_RUNNING:
         shell_app_activate_window (app, NULL, timestamp);
         break;
+      default:
+        g_assert_not_reached();
+        break;
     }
 }
 
@@ -699,7 +709,7 @@ static int
 shell_app_get_last_user_time (ShellApp *app)
 {
   GSList *iter;
-  int last_user_time;
+  guint32 last_user_time;
 
   last_user_time = 0;
 
@@ -709,7 +719,7 @@ shell_app_get_last_user_time (ShellApp *app)
         last_user_time = MAX (last_user_time, meta_window_get_user_time (iter->data));
     }
 
-  return last_user_time;
+  return (int)last_user_time;
 }
 
 /**
@@ -1151,7 +1161,13 @@ shell_app_launch (ShellApp     *app,
   if (app->info == NULL)
     {
       MetaWindow *window = window_backed_app_get_window (app);
-      meta_window_activate (window, timestamp);
+      /* We don't use an error return if there no longer any windows, because the
+       * user attempting to activate a stale window backed app isn't something
+       * we would expect the caller to meaningfully handle or display an error
+       * message to the user.
+       */
+      if (window)
+        meta_window_activate (window, timestamp);
       return TRUE;
     }
 
