@@ -124,6 +124,9 @@ void     shell_global_init_xdnd                 (ShellGlobal  *global);
 
 void     shell_global_reexec_self               (ShellGlobal  *global);
 
+void     shell_global_log_structured            (const char *message,
+                                                 const char *const *keys);
+
 const char *     shell_global_get_session_mode  (ShellGlobal  *global);
 
 void     shell_global_set_runtime_state         (ShellGlobal  *global,
