@@ -4,6 +4,7 @@
 
 #include <string.h>
 
+#include <meta/meta-enum-types.h>
 #include <meta/keybindings.h>
 
 #include "shell-wm-private.h"
@@ -20,8 +21,7 @@ enum
 {
   MINIMIZE,
   UNMINIMIZE,
-  MAXIMIZE,
-  UNMAXIMIZE,
+  SIZE_CHANGE,
   MAP,
   DESTROY,
   SWITCH_WORKSPACE,
@@ -74,22 +74,14 @@ shell_wm_class_init (ShellWMClass *klass)
                   NULL, NULL, NULL,
                   G_TYPE_NONE, 1,
                   META_TYPE_WINDOW_ACTOR);
-  shell_wm_signals[MAXIMIZE] =
-    g_signal_new ("maximize",
+  shell_wm_signals[SIZE_CHANGE] =
+    g_signal_new ("size-change",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0,
                   NULL, NULL, NULL,
-                  G_TYPE_NONE, 5,
-                  META_TYPE_WINDOW_ACTOR, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
-  shell_wm_signals[UNMAXIMIZE] =
-    g_signal_new ("unmaximize",
-                  G_TYPE_FROM_CLASS (klass),
-                  G_SIGNAL_RUN_LAST,
-                  0,
-                  NULL, NULL, NULL,
-                  G_TYPE_NONE, 5,
-                  META_TYPE_WINDOW_ACTOR, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
+                  G_TYPE_NONE, 4,
+                  META_TYPE_WINDOW_ACTOR, META_TYPE_SIZE_CHANGE, META_TYPE_RECTANGLE, META_TYPE_RECTANGLE);
   shell_wm_signals[MAP] =
     g_signal_new ("map",
                   G_TYPE_FROM_CLASS (klass),
@@ -220,32 +212,11 @@ shell_wm_completed_unminimize (ShellWM         *wm,
   meta_plugin_unminimize_completed (wm->plugin, actor);
 }
 
-/**
- * shell_wm_completed_maximize:
- * @wm: the ShellWM
- * @actor: the MetaWindowActor actor
- *
- * The plugin must call this when it has completed a window maximize effect.
- **/
 void
-shell_wm_completed_maximize (ShellWM         *wm,
-                             MetaWindowActor *actor)
+shell_wm_completed_size_change (ShellWM         *wm,
+                                MetaWindowActor *actor)
 {
-  meta_plugin_maximize_completed (wm->plugin, actor);
-}
-
-/**
- * shell_wm_completed_unmaximize:
- * @wm: the ShellWM
- * @actor: the MetaWindowActor actor
- *
- * The plugin must call this when it has completed a window unmaximize effect.
- **/
-void
-shell_wm_completed_unmaximize (ShellWM         *wm,
-                               MetaWindowActor *actor)
-{
-  meta_plugin_unmaximize_completed (wm->plugin, actor);
+  meta_plugin_size_change_completed (wm->plugin, actor);
 }
 
 /**
@@ -359,25 +330,13 @@ _shell_wm_unminimize (ShellWM         *wm,
 }
 
 void
-_shell_wm_maximize (ShellWM         *wm,
-                    MetaWindowActor *actor,
-                    int              target_x,
-                    int              target_y,
-                    int              target_width,
-                    int              target_height)
+_shell_wm_size_change (ShellWM         *wm,
+                       MetaWindowActor *actor,
+                       MetaSizeChange   which_change,
+                       MetaRectangle   *old_frame_rect,
+                       MetaRectangle   *old_buffer_rect)
 {
-  g_signal_emit (wm, shell_wm_signals[MAXIMIZE], 0, actor, target_x, target_y, target_width, target_height);
-}
-
-void
-_shell_wm_unmaximize (ShellWM         *wm,
-                      MetaWindowActor *actor,
-                      int              target_x,
-                      int              target_y,
-                      int              target_width,
-                      int              target_height)
-{
-  g_signal_emit (wm, shell_wm_signals[UNMAXIMIZE], 0, actor, target_x, target_y, target_width, target_height);
+  g_signal_emit (wm, shell_wm_signals[SIZE_CHANGE], 0, actor, which_change, old_frame_rect, old_buffer_rect);
 }
 
 void
